@@ -29,11 +29,7 @@
 
 #define __GOA_BACKEND_INSIDE_GOA_BACKEND_H__
 #include <goabackend/goabackendtypes.h>
-#include <goabackend/goalogging.h>
-#include <goabackend/goaeditablelabel.h>
 #include <goabackend/goaprovider.h>
-#include <goabackend/goagoogleprovider.h>
-#include <goabackend/goafacebookprovider.h>
 #undef __GOA_BACKEND_INSIDE_GOA_BACKEND_H__
 
 #endif /* __GOA_BACKEND_H__ */
